#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Convenience wrapper for running randopass directly from source tree.
""" 
 
from randopass.randopass import main
 
if __name__ == '__main__':
    main()


"""
randopass: strong random English-word passphrases
"""
__version__="0.1.5"

"""secrets package is used for randomness"""
import secrets
import sys
import importlib
from randopass.dictionaries import english
from randopass.dictionaries import english_simple
from randopass.dictionaries import afrikaans

capitalizations = ['lower', 'capital', 'upper', 'any', 'wild']
languages = ['english', 'english_simple', 'afrikaans']
dictionary = english.words()

def getVersion():
    return __version__

def main():
    numWords = 4
    capitalization = capitalizations[0]
    language = languages[0]
    args = [a for a in sys.argv[1:]]
    for arg in args:
        try:
            numWords = int(arg)
        except:
            if arg.lower() in capitalizations:
                capitalization = arg
            elif arg.lower() in languages:
                language = arg
            else: 
                print("invalid argument", file=sys.stderr)
                return
    language_module = importlib.import_module('randopass.dictionaries.'+language)
    dictionary = language_module.words()
    phrase = ''.join(getPass(numWords, capitalization, dictionary))
    print('Passphrase:\n', phrase, file=sys.stdout)
    del phrase

def getPass(length=4, capitalization=capitalizations[0], language=languages[0]):
    """returns passphrase composed of _length_ random words (4 by default)"""

    def capitalize(string, capitalization):
        capitalization = capitalization.lower()
        if capitalization == "upper":
            return string.upper()
        elif capitalization == "capital":
            return string.capitalize()
        elif capitalization == "any":
            return capitalize(string, secrets.choice(list(Capitalization)[:-2]))
        elif capitalization == "wild":
            return ''.join([capitalize(char, secrets.choice(list(Capitalization)[:-2])) for char in string])
        else:
            return string.lower()

    return [capitalize(secrets.choice(dictionary), capitalization) for i in range(length)]




# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
import re
from os import getcwd, path
import pathlib

# here = pathlib.Path(__file__).parent.resolve()

package_dir = getcwd()+path.sep

# with open(package_dir + 'README.md') as f:
#     readme = f.read()
    
with open(package_dir + 'LICENSE') as f:
    license = f.read()

with open('randopass/randopass.py') as f:
    version = re.search(
    '^__version__\s*=\s*"(.*)"',
    f.read(),
    re.M
    ).group(1).strip('\n')

setup(
    name='randopass',
    version=version,
    description='Generate easy but secure passphrases',
    long_description='The long description isn\'t working, so please checkout the github page: (https://github.com/mikewillems/randopass/) for full instructions.',
    # long_description = (here / 'README.md').read_text(encoding='utf-8'),
    # long_description_content_type='text/markdown',
    author='Mike Willems',
    author_email='themikewillems@gmail.com',
    url='https://github.com/mikewillems/randopass/',
    license='MIT',
    packages=find_packages(exclude=('tests', 'docs')),
    include_package_data = True,
    entry_points={
        'console_scripts': ['randopass=randopass.randopass:main'],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)